
# 24 picked since that's when the package was updated to contain a version
# capable of python3.  If we're willing to push the update to older Fedora
# releases, the python3 package can go to older releases as well.
%if 0%{?fedora} >= 23 || 0%{?rhel} >= 7
%global with_python3 1
%else
%global with_python3 0
%endif

%if (0%{?fedora} && 0%{?fedora} <= 31) || (0%{?rhel} && 0%{?rhel} < 8)
%global with_python2 1
%else
%global with_python2 0
%endif

Name:           python-daemon
Version:        2.2.3
Release:        5%{?dist}
Summary:        Library to implement a well-behaved Unix daemon process

# Some build scripts and test franework are licensed GPLv3+ but htose aren't shipped
License:        ASL2.0
URL:            http://pypi.python.org/pypi/python-daemon/
Source0:        https://files.pythonhosted.org/packages/source/p/%{name}/%{name}-%{version}.tar.gz
# Fix python3.8 socket tests. Already upstream.
Patch0:         https://pagure.io/python-daemon/c/b7089121e305ef29dee9b72bfdb8b1496ffed48c.patch
# Fix the test suite in py2
Patch1:         0001-Mock-the-.__class__-attribute-so-tests-pass-in-py2.patch

BuildArch:      noarch

%if 0%{?with_python2}
BuildRequires:  python2-devel, python2-setuptools
BuildRequires:  python2-docutils
%if 0%{?el7}
BuildRequires:  python-testscenarios
BuildRequires:  python-lockfile
%else
BuildRequires:  python2-testscenarios
BuildRequires:  python2-lockfile
%endif
BuildRequires:  python2-mock
%endif

%if 0%{?with_python3}
BuildRequires:  python%{python3_pkgversion}-devel, python%{python3_pkgversion}-setuptools
%{!?el7:BuildRequires:  python%{python3_pkgversion}-testscenarios}
BuildRequires:  python%{python3_pkgversion}-docutils
%{!?el7:BuildRequires:  python%{python3_pkgversion}-lockfile}
BuildRequires:  python%{python3_pkgversion}-mock
%{!?el7:BuildRequires:  python%{python3_pkgversion}-testtools}
%endif

%global _description\
This library implements the well-behaved daemon specification of PEP 3143,\
"Standard daemon process library".\
\
This is the python2 version of the library.

%description %_description

%if 0%{?with_python2}
%package -n python2-daemon
Summary: %summary
Requires:       python2-lockfile
Requires:       python2-docutils
%{?python_provide:%python_provide python2-daemon}

%description -n python2-daemon %_description
%endif

%if 0%{?with_python3}
%package -n python%{python3_pkgversion}-daemon
Summary:        Library to implement a well-behaved Unix daemon process
Requires:       python%{python3_pkgversion}-lockfile
Requires:       python%{python3_pkgversion}-docutils
%{?python_provide:%python_provide python3-daemon}

%description -n python%{python3_pkgversion}-daemon
This library implements the well-behaved daemon specification of PEP 3143,
"Standard daemon process library".

This is the python3 version of the library.
%endif

%prep
%autosetup -p1

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -ar . %{py3dir}
%endif

%build
%if 0%{?with_python2}
%py2_build
%endif

%if 0%{?with_python3}
pushd %{py3dir}
%py3_build
popd
%endif

%install
%if 0%{?with_python2}
%py2_install
rm -fr %{buildroot}%{python2_sitelib}/tests
%endif

%if 0%{?with_python3}
pushd %{py3dir}
%py3_install
rm -fr %{buildroot}%{python3_sitelib}/tests
popd
%endif


# Test suite requires minimock and lockfile
%check
%if 0%{?with_python2}
PYTHONPATH=$(pwd) %{__python2} -m unittest discover
%endif

%if 0%{?with_python3} && 0%{!?el7}
pushd %{py3dir}
PYTHONPATH=$(pwd) %{__python3} -m unittest discover
%endif

%if 0%{?with_python2}
%files -n python2-daemon
%license LICENSE.ASF-2
%{python2_sitelib}/daemon/
%{python2_sitelib}/python_daemon-%{version}-py%{python2_version}.egg-info/
%endif

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-daemon
%license LICENSE.ASF-2
%{python3_sitelib}/daemon/
%{python3_sitelib}/python_daemon-%{version}-py%{python3_version}.egg-info/
%endif

%changelog
* Tue Aug 20 2019 Pierre-Yves Chibon <pingou@pingoured.fr> - 2.2.3-5
- Patch the test suite so it passes with py2

* Sun Aug 18 2019 Miro Hrončok <mhroncok@redhat.com> - 2.2.3-4
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Jun 29 2019 Kevin Fenzi <kevin@scrye.com> - 2.2.3-2
- Add patch for socket tests in python 3.8. Fixes bug #1695802

* Tue Feb 12 2019 Alfredo Moralejo <amoralej@redhat.com> - 2.2.3-1
- Update to 2.2.3

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 18 2018 Miro Hrončok <mhroncok@redhat.com> - 2.1.2-9
- Rebuilt for Python 3.7

* Mon Feb 12 2018 Iryna Shcherbina <ishcherb@redhat.com> - 2.1.2-8
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Dec 17 2017 Kevin Fenzi <kevin@scrye.com> - 2.1.2-6
- Add dep on python2-docutils. Fixes bug #1478196

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.1.2-5
- Python 2 binary package renamed to python2-daemon
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.1.2-2
- Rebuild for Python 3.6

* Wed Nov 09 2016 Kevin Fenzi <kevin@scrye.com> - 2.1.2-1
- Update to 2.1.2. Fixes bug #1389593

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Sun Apr 10 2016 Kevin Fenzi <kevin@scrye.com> - 2.1.1-1
- Update to 2.1.1. Fixes bug #1234933

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 30 2015 Toshio Kuratomi <toshio@fedoraproject.org> - - 2.1.0-1
- Update to newer upstream.
- Create a python3 subpackage since upstream supports it
- Note that newer upstream has relicensed to Apache 2.0

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Aug  4 2014 Thomas Spura <tomspur@fedoraproject.org> - 1.6-7
- enable tests again as lockfile was fixed

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jul 14 2011 Kushal Das <kushal@fedoraproject.org> - 1.6-1
- New release of source

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Dec 23 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.5.2-1
- add missing BR: python-nose
- also add lockfile as R (bug #513546)
- update to 1.5.2

* Wed Dec 23 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.5.1-2
- add missing BR: minimock and lockfile -> testsuite works again
- remove patch, use sed instead

* Wed Oct 07 2009 Luke Macken <lmacken@redhat.com> - 1.5.1-1
- Update to 1.5.1
- Remove conflicting files (#512760)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 24 2009 Kushal Das <kushal@fedoraproject.org> 1.4.6-1
- Initial release

